@@ -1,9 +1,11 @@
-from lib2to3.fixer_util import FromImport, Newline, find_root
+from __future__ import absolute_import
+
+from lib2to3 import fixer_util
 from lib2to3.pytree import Leaf, Node
 from lib2to3.pygram import python_symbols as syms
 from lib2to3.pgen2 import token
 
-__version__ = '0.3'
+__version__ = '0.4'
 
 def check_future_import(node):
     """If this is a future import, return set of symbols that are imported,
@@ -36,12 +38,12 @@ def check_future_import(node):
         return set([node.value])
     elif node.type == token.NAME:
         return set([node.value])
-    else:
+    else:  # pragma: no cover
         assert 0, "strange import"
 
 def add_future(node, symbol):
 
-    root = find_root(node)
+    root = fixer_util.find_root(node)
 
     for idx, node in enumerate(root.children):
         if node.type == syms.simple_stmt and \
@@ -56,6 +58,22 @@ def add_future(node, symbol):
             # already imported
             return
 
-    import_ = FromImport('__future__', [Leaf(token.NAME, symbol, prefix=" ")])
-    children = [import_, Newline()]
+    import_ = fixer_util.FromImport('__future__',
+                                    [Leaf(token.NAME, symbol, prefix=" ")])
+    children = [import_, fixer_util.Newline()]
     root.insert_child(idx, Node(syms.simple_stmt, children))
+
+
+def touch_import(package, name, node):
+    add_future(node, 'absolute_import')
+    fixer_util.touch_import(package, name, node)
+
+
+def is_listcomp(node):
+    return (isinstance(node, Node) and
+             node.type == syms.atom and
+             len(node.children) >= 2 and
+             isinstance(node.children[0], Leaf) and
+             node.children[0].value == '[' and
+             isinstance(node.children[-1], Leaf) and
+             node.children[-1].value == ']')
