@@ -8,7 +8,7 @@ lib2to3_fix_names = set([
     'lib2to3.fixes.fix_funcattrs',
     'lib2to3.fixes.fix_has_key',
     'lib2to3.fixes.fix_idioms',
-    'lib2to3.fixes.fix_import',
+    'lib2to3.fixes.fix_long',
     'lib2to3.fixes.fix_methodattrs',
     'lib2to3.fixes.fix_ne',
     'lib2to3.fixes.fix_numliterals',
@@ -23,19 +23,27 @@ lib2to3_fix_names = set([
     'lib2to3.fixes.fix_tuple_params',
     'lib2to3.fixes.fix_types',
     'lib2to3.fixes.fix_ws_comma',
-    'lib2to3.fixes.fix_xrange',
     'lib2to3.fixes.fix_xreadlines'
 ])
 
 # fixes that involve using six
 six_fix_names = set([
-    'libmodernize.fixes.fix_dict',
+    'libmodernize.fixes.fix_basestring',
+    'libmodernize.fixes.fix_dict_six',
     'libmodernize.fixes.fix_filter',
+    'libmodernize.fixes.fix_imports_six',
+    'libmodernize.fixes.fix_input_six',
+    'libmodernize.fixes.fix_int_long_tuple',
     'libmodernize.fixes.fix_map',
-    'libmodernize.fixes.fix_next',
-    'libmodernize.fixes.fix_range',
+    'libmodernize.fixes.fix_metaclass',
     'libmodernize.fixes.fix_raise_six',
     'libmodernize.fixes.fix_unicode',
+    'libmodernize.fixes.fix_unicode_type',
+    'libmodernize.fixes.fix_xrange_six',
     'libmodernize.fixes.fix_zip',
-    'libmodernize.fixes.fix_metaclass'
-    ])
+])
+
+# Fixes that are opt-in only.
+opt_in_fix_names = set([
+    'libmodernize.fixes.fix_open',
+])
