@@ -1,4 +1,11 @@
-from __future__ import print_function
+"""\
+Python           _              _
+   _ __  ___  __| |___ _ _ _ _ (_)______
+  | '  \/ _ \/ _` / -_) '_| ' \| |_ / -_)
+  |_|_|_\___/\__,_\___|_| |_||_|_/__\___|\
+"""
+
+from __future__ import absolute_import, print_function
 
 import sys
 import logging
@@ -7,8 +14,18 @@ import optparse
 from lib2to3.main import warn, StdoutRefactoringTool
 from lib2to3 import refactor
 
-from libmodernize.fixes import lib2to3_fix_names, six_fix_names
+from libmodernize import __version__
+from libmodernize.fixes import lib2to3_fix_names, six_fix_names, opt_in_fix_names
 
+usage = __doc__ + """\
+ %s
+
+Usage: modernize [options] file|dir ...
+""" % __version__
+
+def format_usage(usage):
+    """Method that doesn't output "Usage:" prefix"""
+    return usage
 
 def main(args=None):
     """Main program.
@@ -16,34 +33,36 @@ def main(args=None):
     Returns a suggested exit status (0, 1, 2).
     """
     # Set up option parser
-    parser = optparse.OptionParser(usage="modernize [options] file|dir ...")
+    parser = optparse.OptionParser(usage=usage,
+                                   version="modernize %s" % __version__)
+    parser.formatter.format_usage = format_usage
     parser.add_option("-d", "--doctests_only", action="store_true",
-                      help="Fix up doctests only")
+                      help="Fix up doctests only.")
     parser.add_option("-f", "--fix", action="append", default=[],
-                      help="Each FIX specifies a transformation; default: all")
+                      help="Each FIX specifies a transformation; '-f default' includes default fixers.")
     parser.add_option("-j", "--processes", action="store", default=1,
-                      type="int", help="Run 2to3 concurrently")
+                      type="int", help="Run 2to3 concurrently.")
     parser.add_option("-x", "--nofix", action="append", default=[],
                       help="Prevent a fixer from being run.")
     parser.add_option("-l", "--list-fixes", action="store_true",
-                      help="List available transformations")
+                      help="List available transformations.")
     parser.add_option("-p", "--print-function", action="store_true",
-                      help="Modify the grammar so that print() is a function")
+                      help="Modify the grammar so that print() is a function.")
     parser.add_option("-v", "--verbose", action="store_true",
-                      help="More verbose logging")
+                      help="Show more verbose logging.")
     parser.add_option("--no-diffs", action="store_true",
-                      help="Don't show diffs of the refactoring")
+                      help="Don't show diffs of the refactoring.")
     parser.add_option("-w", "--write", action="store_true",
-                      help="Write back modified files")
+                      help="Write back modified files.")
     parser.add_option("-n", "--nobackups", action="store_true", default=False,
                       help="Don't write backups for modified files.")
     parser.add_option("--six-unicode", action="store_true", default=False,
-                      help="Wrap unicode literals in six.u()")
+                      help="Wrap unicode literals in six.u().")
     parser.add_option("--future-unicode", action="store_true", default=False,
                       help="Use 'from __future__ import unicode_literals'"
                       "(only useful for Python 2.6+).")
     parser.add_option("--no-six", action="store_true", default=False,
-                      help="Exclude fixes that depend on the six package")
+                      help="Exclude fixes that depend on the six package.")
 
     fixer_pkg = 'libmodernize.fixes'
     avail_fixes = set(refactor.get_fixers_from_package(fixer_pkg))
@@ -54,9 +73,9 @@ def main(args=None):
     flags = {}
     options, args = parser.parse_args(args)
     if not options.write and options.no_diffs:
-        warn("not writing files and not printing diffs; that's not very useful")
+        warn("Not writing files and not printing diffs; that's not very useful.")
     if not options.write and options.nobackups:
-        parser.error("Can't use -n without -w")
+        parser.error("Can't use '-n' without '-w'.")
     if options.list_fixes:
         print("Available transformations for the -f/--fix option:")
         for fixname in sorted(avail_fixes):
@@ -81,6 +100,7 @@ def main(args=None):
 
     # Initialize the refactoring tool
     unwanted_fixes = set(options.nofix)
+    default_fixes = avail_fixes.difference(opt_in_fix_names)
 
     # Remove unicode fixers depending on command line options
     if options.six_unicode:
@@ -95,15 +115,15 @@ def main(args=None):
         unwanted_fixes.update(six_fix_names)
     explicit = set()
     if options.fix:
-        all_present = False
+        default_present = False
         for fix in options.fix:
-            if fix == "all":
-                all_present = True
+            if fix == "default":
+                default_present = True
             else:
                 explicit.add(fix)
-        requested = avail_fixes.union(explicit) if all_present else explicit
+        requested = default_fixes.union(explicit) if default_present else explicit
     else:
-        requested = avail_fixes.union(explicit)
+        requested = default_fixes
     fixer_names = requested.difference(unwanted_fixes)
     rt = StdoutRefactoringTool(sorted(fixer_names), flags, sorted(explicit),
                                options.nobackups, not options.no_diffs)
@@ -116,9 +136,9 @@ def main(args=None):
             try:
                 rt.refactor(args, options.write, options.doctests_only,
                             options.processes)
-            except refactor.MultiprocessingUnsupported:
+            except refactor.MultiprocessingUnsupported: # pragma: no cover
                 assert options.processes > 1
-                print("Sorry, -j isn't supported on this platform.", 
+                print("Sorry, -j isn't supported on this platform.",
                       file=sys.stderr)
                 return 1
         rt.summarize()
